Struct os_socketaddr::OsSocketAddr [−][src]
Implementations
impl OsSocketAddr[src]
pub fn new() -> Self[src]
Create a new empty socket address
pub unsafe fn from_raw_parts(ptr: *const u8, len: usize) -> Self[src]
Create a new socket address from a raw slice
Panics
Panics if len is bigger that the size of libc::sockaddr_in6
pub fn from(addr: SocketAddr) -> Self[src]
Create a new socket address from a std::net::SocketAddr object
pub fn into_addr(self) -> Option<SocketAddr>[src]
Attempt to convert the internal buffer into a std::net::SocketAddr object
The internal buffer is assumed to be a libc::sockaddr.
If the value of .sa_family resolves to AF_INET or AF_INET6 then the buffer is
converted into SocketAddr, otherwise the function returns None.
pub fn len(&self) -> socklen_t[src]
Return the length of the address
The result depends on the value of .sa_family in the internal buffer:
AF_INET-> the size ofsockaddr_inAF_INET6-> the size ofsockaddr_in6- other -> 0
pub fn capacity(&self) -> socklen_t[src]
Return the size of the internal buffer
pub fn as_ptr(&self) -> *const sockaddr[src]
Get a pointer to the internal buffer
pub fn as_mut_ptr(&mut self) -> *mut sockaddr[src]
Get a mutable pointer to the internal buffer